# Ceilopyter

[![Run tests](https://github.com/actris-cloudnet/ceilopyter/actions/workflows/test.yml/badge.svg)](https://github.com/actris-cloudnet/ceilopyter/actions/workflows/test.yml)
[![PyPI version](https://badge.fury.io/py/ceilopyter.svg)](https://badge.fury.io/py/ceilopyter)

Python package for reading ceilometer data.

## Supported ceilometers

- Campbell Scientific CS135
- Vaisala CL31
- Vaisala CL51
- Vaisala CT25K

## License

MIT
